@@ -11,7 +11,10 @@ class SchedulerService(Launchable):
         scheduler (GraiaScheduler): 任务计划器
     """
 
+    id = "scheduler.service"
+
     def __init__(self, scheduler: GraiaScheduler) -> None:
+        super().__init__()
         self.scheduler = scheduler
 
     @property
